import 'dotenv/config';
import { drizzle } from 'drizzle-orm/bun-sqlite';
import { publisherTable, sourceTable, chunkTable, tableTable, outcomeTable } from './schema';
import { publishersData, sourcesData, chunksData, tableData, outcomeData } from './data'

const db = drizzle({ connection: { source: process.env.DB_FILE_NAME! } });

async function deleteData() {
  await db.delete(outcomeTable)
  console.log('- Outcomes Deleted')

  await db.delete(tableTable)
  console.log('- (roll) Tables Deleted')

  await db.delete(chunkTable)
  console.log('- Chunks Deleted')

  await db.delete(sourceTable)
  console.log('- Sources Deleted')

  await db.delete(publisherTable)
  console.log('- Publishers Deleted')
}

async function seedData() {
  const publishers = await db.insert(publisherTable).values(publishersData()).returning()
  console.log('- Publishers Created')

  const sources = await db.insert(sourceTable).values(sourcesData(publishers)).returning()
  console.log('- Sources Created')

  const chunks = await db.insert(chunkTable).values(chunksData(sources)).returning()
  console.log('- Chunks Created')

  const tables = await db.insert(tableTable).values(tableData(chunks)).returning()
  console.log('- (roll) Tables Created')

  await db.insert(outcomeTable).values(outcomeData(tables)).returning()
  console.log('- Outcomes Created')
}

(async () => {
  console.log('Deleting Existing Data...')
  await deleteData();
  console.log('Data Deleted!\n=====\nSeeding Data...')
  await seedData();
  console.log('Data Seeded!')
})().catch(err => {
  console.error(err);
});
